@@ -17,6 +17,7 @@ pub struct Pr<'a> {
     pub files: Files<'a>,
     pub blame: bool,
     pub labels: Labels<'a>,
+    pub requested: bool,
     pub codeowner: bool,
 }
 
@@ -28,6 +29,13 @@ pub enum TestsState {
     None,
 }
 
+#[derive(Serialize)]
+pub enum ReviewRequested {
+    RequestedAsCodeOwner,
+    RequestedNotAsCodeOwner,
+    NotRequested,
+}
+
 #[derive(Serialize)]
 pub struct Files<'a>(pub Vec<&'a str>);
 
@@ -57,6 +65,7 @@ pub struct Score {
     pub deletions: f64,
     pub based_on_main_branch: f64,
     pub blame: f64,
+    pub requested: f64,
     pub codeowner: f64,
 }
 
@@ -78,6 +87,7 @@ impl Score {
             deletions: pr.deletions as f64 * -0.1,
             based_on_main_branch: pr.based_on_main_branch as u8 as f64 * 200.0,
             blame: pr.blame as u8 as f64 * 400.0,
+            requested: pr.requested as u8 as f64 * 800.0,
             codeowner: pr.codeowner as u8 as f64 * 400.0,
         }
     }
@@ -92,6 +102,7 @@ impl Score {
             + self.deletions
             + self.based_on_main_branch
             + self.blame
+            + self.requested
             + self.codeowner
     }
 }
@@ -166,6 +177,7 @@ mod tests {
             files: Files(vec![]),
             blame: false,
             labels: Labels(vec![]),
+            requested: true,
             codeowner: false,
         };
 
